@@ -205,19 +205,8 @@ if [ -f /root/whp/scripts/post-update.sh ]; then
     /root/whp/scripts/post-update.sh "$CURRENT_VERSION" "$NEW_VERSION"
 fi
 
-# Restart services
-echo ""
-echo "Restarting services..."
-systemctl restart httpd php-fpm
-
-# Check if services started successfully
-sleep 2
-if ! systemctl is-active --quiet httpd; then
-    echo -e "${RED}Warning: Apache failed to start${NC}"
-fi
-if ! systemctl is-active --quiet php-fpm; then
-    echo -e "${RED}Warning: PHP-FPM failed to start${NC}"
-fi
+# Services typically don't need restart for WHP updates
+# If restart is needed, it should be done via post-update script
 
 echo ""
 echo -e "${GREEN}Update complete!${NC}"
